import os
import pathlib
from typing import Dict, List, Tuple

import pytest


# contents of gridmap file, parsed contents
GridmapDataFixtureType = Tuple[str, Dict[str, List[str]]]

# path to gridmap file, parsed contents
GridmapFileFixtureType = Tuple[os.PathLike, Dict[str, List[str]]]


@pytest.fixture
def gridmap_data() -> GridmapDataFixtureType:
    return (
        """\
/C=US/O=Globus/OU=Test/CN=User1	local1
/C=US/O=Globus/OU=Test/CN=User2	local2
# Some comment line
"/C=US/O=Globus/OU=Test/CN=Quoted User1"  local3,   local4
"/C=US/O=Globus/OU=Test/CN=Quoted \\"User\\"2"  local5,local6, local7
/C=US/O=Globus/OU=Test/CN=User2	local8
/C=US/O=Globus/OU=Test/CN=Email1 local9
""",
        {
            "/C=US/O=Globus/OU=Test/CN=User1": ["local1"],
            "/C=US/O=Globus/OU=Test/CN=User2": ["local2", "local8"],
            "/C=US/O=Globus/OU=Test/CN=Quoted User1": ["local3", "local4"],
            '/C=US/O=Globus/OU=Test/CN=Quoted "User"2': ["local5", "local6", "local7"],
            "/C=US/O=Globus/OU=Test/CN=Email1": ["local9"],
        },
    )


@pytest.fixture
def gridmap_file(
    tmp_path: pathlib.Path, gridmap_data: GridmapDataFixtureType
) -> GridmapFileFixtureType:
    contents, parsed = gridmap_data
    name = tmp_path / "gridmap"

    with open(name, "w") as f:
        print(contents, file=f)

    return name, parsed
